/*
 *========================================================================
 * See copyright in copyright.h and the accompanying file COPYING
 *========================================================================
 */

#include "c_lib_project.h"
/*
 * Can ONLY include once in toplevel source -- defines strings for
 * whole application.
 */
#include "copyright.h"

/*
 * For Command Line Interface (CLI) dieharder, main() is just a shell for
 * routines that parse the command line, do all the requested work, and
 * then exit cleanly.  Interactive User Interfaces (UIs) have an internal
 * interactive loop.  The initialization commands are therefore split up
 * so that things that must be done once per invocation of the binary
 * itself are cleanly distinct from things that must be done once per
 * selection of rng to be tested, that are in turn distinct from things
 * that must be done once per test.  See comments around each call below.
 */
int main(int argc, char *argv[]) 
{

 int i;

 /*
  * set_globals picks the default values that control the CLI/UI (not the
  * tests, which have internal defaults).  If you are writing your own UI,
  * replace or patch set_globals with your own choices if desired.  Note
  * that some of the variables set control e.g. dieharder stdout output
  * options that will likely be irrelevant to a GUI or tool interface.
  */
 set_globals();

 /*
  * parsecl executes CLI-specific code that overrides the defaults set by
  * set_globals with choices selected via command line options.  A UI
  * should almost certainly just reset the global variables directly and
  * not use parsecl().  parsecl() (and the options available to the CLI)
  * is subject to change without notice as the CLI evolves, but the global
  * variables themselves should change much more slowly.
  */
 parsecl(argc,argv);

 /*
  * Here is the only actual code in this example.  It calls the library
  * function "hello()".
  */
 hello();

 /*
  * This ends the core loop for a non-CLI interactive UI.  GUIs will
  * typically exit directly from the event loop.  Tool UIs may well fall
  * through, and the CLI simply proceeds sequentially to exit.  It isn't
  * strictly necessary to execute an exit() command at the end, but it
  * does make the code a bit clearer (and let's one choose an exit code,
  * if that might ever matter.  Exit code 0 clearly means "completed
  * normally".
  */
 exit(0);

}
