/*
 * $Id: parsecl.c 477 2008-10-08 19:11:30Z rgbatduke $
 *
 * See copyright in copyright.h and the accompanying file COPYING
 *
 */

#include "c_lib_project.h"

/*
 * parsecl parses the command line for the project CLI to:
 *
 *  a) override the defaults set by set_globals().
 *  b) handle ill-formed command lines (usage errors)
 *  c) manage all autodocumentation features of dieharder (commands
 *     that cause any of the general output documentation panels to print).
 *
 * With the exception of the usage/documentation pathways (that all exit
 * on completion without executing any test) parsecl does no actual work.
 * Actual dieharder setup and task execution is handled by downstream
 * routines.
 */

void parsecl(int argc, char **argv)
{

 /*
  * Thus far, dieharder has used getopt() to parse the CL.  However, this
  * isn't as flexible as one might like.  To manage CLI-driven control
  * flags and a few other things, we may need to parse out options the
  * hard way in a future release.  The following variables are pretty much
  * all to support getopt and would change if we change parsing tools or
  * strategies.
  */

 int imax,i,c,errflg=0;
 int itmp;
 uint utmp;
 int tflag_tmp = 0,dtest_tmp,gen_tmp;
 extern char *optarg;
 extern int optind, opterr, optopt;
 char *endptr;

 while ((c = getopt(argc,argv,"v:")) != EOF){
   switch (c){
     case 'v':
       verbose = strtol(optarg,(char **) NULL,10);
       printf("# Verbose is now %d\n",verbose);
       break;
     case '?':
       errflg++;
   }
 }

 /*
  * By the time we get here, all the command line options should have
  * been processed, and we are ready to act on them.  There are a small
  * set of options that we act on right away below, mostly associated with
  * the autodocumenting features of the dieharder CLI (only).
  * Interfaces such as Rdieharder should just ifdef them out, or better
  * yet, not use this routine at all since it should invariably be faster
  * and easier to just set the options directly instead of building a
  * fake command line to hand off to parsecl().
  */

 /*
  * Some option was set incorrectly.
  */
 if(errflg){
   Usage();
   exit(0);
 }

 /*
  * If there are no more arguments it is a legal command, so return.
  * We put in the brackets in case you want to do something more with
  * cli arguments before returning.  Note that you can insert code
  * here to pull off the remaining arguments and do them outside of
  * getopt, as well.
  */
 if(argc-optind == 0){
    return;
 }

 /*
  * Leftover commands on the command line are errors and should trigger
  * the standard Usage message and exit.
  */

 Usage();
 

}

